@@ -6,6 +6,9 @@ Mike Hegarty (Github: mhegarty)
 Jul 2018
 """
 
+# Import Models
+from .models import *
+
 # Purge logs
 from .utils import purge_logs
 purge_logs()
\ No newline at end of file
