@@ -3,7 +3,7 @@
 
 from uuid import uuid4
 from random import randint
-from .utils import create_logger
+from utils import create_logger
 
 
 class Game():
@@ -44,18 +44,18 @@ class Game():
     3) Roll. Role the dice and get a result.
 
     4) Evaluate. Check each bet and update payout, working, and settled attributes."""
-    def __init__(self, loglevel=20, arrival_cash=1000.):
+    def __init__(self, loglevel=20, arrival_cash=1000., minimum_bet=10., max_odds=10.):
         self._id     = None
         self.logger  = create_logger(self.id)
         self.logger.setLevel(loglevel)
         self.logger.debug(f'Game is loading, id: {self.id}')
         self.history = []
         
-        self.allow_credit_rail = False  # Allow us to go negative
+        self.allow_credit_rail = False  # Allow us to go negative, never.
         
         self.arrival_cash  = arrival_cash
-        self.minimum_bet   = 10.  # The table minimum bet (typically $10)
-        self.max_odds      = 10.  # The table limit on odds bets (typically 10x come or pass)
+        self.minimum_bet   = minimum_bet  # The table minimum bet
+        self.max_odds      = max_odds     # The table limit on odds bets
         
         self.puck  = None
         self.rolls = []
@@ -122,15 +122,21 @@ class Game():
         if (not self.allow_credit_rail) and (bet.amount > self.rail_balance):
              raise AssertionError('You are bankrupt. Bet rejected')
         
+        # Catch illogical PassBet? Move it to odds?
+        # no, because in some case may want to increase
+        #     the amount on the pass line, if you have max
+        #     odds on already and want moar.
+
         # Catch illogical come bet, move it to the pass line
         if (not self.puck) & (type(bet) is ComeBet):
-            raise AssertionError('You are placing a come bet with the puck off. Moving to the line.')
+            bet = PassBet(bet.amount)
+            self.logger.warning('[Table] You placed a come bet with the puck off. We moved it to the pass line.')
         
         # Reject point odds bets without a come on point
         if type(bet) is PointOddsBet:
             working_come_points = [bet.point for bet in self.unsettled_bets if (type(bet) is ComeBet)]
             if bet.point not in working_come_points:
-                raise AssertionError('You tried to place an odds bet with no come. Bet amount set to zero')
+                raise AssertionError(f'You tried to put odds on {bet.point} with no comebet there. Bet was rejected.')
 
         # Bet has been validated
         # Assign the bet to this game
